@@ -429,15 +429,18 @@ size_t ArrayT<Value>::footprint() const {
 //------------------------------------------------------------------------------
 
 template <typename Value>
-bool ArrayT<Value>::accMap() const {
-    if (not acc_map_) {
-#if ATLAS_GRIDTOOLS_STORAGE_BACKEND_CUDA && ATLAS_HAVE_ACC
-        atlas_acc_map_data((void*)host_data<Value>(), (void*)device_data<Value>(),
-                           spec_.allocatedSize() * sizeof(Value));
-        acc_map_ = true;
-#endif
-    }
-    return acc_map_;
+void ArrayT<Value>::accMap() const {
+    data_store_->accMap();
+}
+
+template <typename Value>
+void ArrayT<Value>::accUnmap() const {
+    data_store_->accUnmap();
+}
+
+template <typename Value>
+bool ArrayT<Value>::accMapped() const {
+    return data_store_->accMapped();
 }
 
 //------------------------------------------------------------------------------
